@@ -1,4 +1,5 @@
 """nile common module."""
+import logging
 import os
 
 from nile.common import DEPLOYMENTS_FILENAME
@@ -14,9 +15,9 @@ def register(address, abi, network, alias):
 
     with open(file, "a") as fp:
         if alias is not None:
-            print(f"📦 Registering deployment as {alias} in {file}")
+            logging.info(f"📦 Registering deployment as {alias} in {file}")
         else:
-            print(f"📦 Registering {address} in {file}")
+            logging.info(f"📦 Registering {address} in {file}")
 
         fp.write(f"{address}:{abi}")
         if alias is not None:
@@ -39,7 +40,7 @@ def load(identifier, network):
 
     with open(file) as fp:
         for line in fp:
-            [address, abi, *alias] = line.split(":")
-            identifiers = [x.strip() for x in [address] + alias]
+            [address, abi, *alias] = line.strip().split(":")
+            identifiers = [x for x in [address] + alias]
             if identifier in identifiers:
                 yield address, abi
